@@ -195,6 +195,9 @@ $(document).ready(function() {
     var confirmPasswordTimer;
     var revealTimers = {};
     
+    // Get CSRF token for API requests
+    var csrfToken = '<?php echo isset($_SESSION['csrf_token']) ? $_SESSION['csrf_token'] : ''; ?>';
+    
     // Simplified toggle function using Font Awesome icons
     function togglePasswordField($input, $iconElement) {
         var inputId = $input.attr('id');
@@ -242,7 +245,13 @@ $(document).ready(function() {
     
     // Generate password button
     $('#generatePassword').click(function() {
-        $.get('/api/change-password.php?action=generate&length=16')
+        $.ajax({
+            url: '/api/change-password.php?action=generate&length=16',
+            method: 'GET',
+            headers: {
+                'X-CSRF-Token': csrfToken
+            }
+        })
             .done(function(response) {
                 if (response.status === 'success') {
                     $('#newPassword').val(response.data.password);
@@ -307,7 +316,13 @@ $(document).ready(function() {
     
     // Check password strength via API
     function checkPasswordStrength(password) {
-        $.get('/api/change-password.php?action=check-strength&password=' + encodeURIComponent(password))
+        $.ajax({
+            url: '/api/change-password.php?action=check-strength&password=' + encodeURIComponent(password),
+            method: 'GET',
+            headers: {
+                'X-CSRF-Token': csrfToken
+            }
+        })
             .done(function(response) {
                 if (response.status === 'success') {
                     updatePasswordStrength(password, response.data);
@@ -435,6 +450,9 @@ $(document).ready(function() {
             url: '/api/change-password.php',
             method: 'POST',
             contentType: 'application/json',
+            headers: {
+                'X-CSRF-Token': csrfToken
+            },
             data: JSON.stringify({
                 current_password: currentPass,
                 new_password: newPass,
